Valid DSCP mark values are even numbers between 0 and 56, except 2-6, 42, 44, and 50-54. The full list of valid DSCP marks is: 0, 8, 10, 12, 14, 16, 18, 20, 22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 46, 48, 56.

The maximum KBPS (kilobits per second) value. If you specify this value, must be greater than 0 otherwise max_kbps will have no value.

The maximum burst size (in kilobits). Default is 0.

The minimum KBPS (kilobits per second) value which should be available for port.

The minimum kpps (kilo(1000) packets per second) value which should be available for port.